@@ -20,9 +20,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 #include "svgpart.h"
 
-// KF
-#include <KLocalizedString>
-
 // Qt
 #include <QDataStream>
 
